==> invoice-client-4.1.28-20220105.084715-8-sources.jar: com/xforceplus/seller/invoice/client/model/open/OpenInvoiceUpdateModel.java <==
package com.xforceplus.seller.invoice.client.model.open;

public class OpenInvoiceUpdateModel {
    private String remark;
    private String purchaserName;
    private String purchaserTaxNo;
    private String purchaserAddress;
    private String purchaserTel;
    private String purchaserBankName;
    private String purchaserBankAccount;

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getPurchaserName() {
        return purchaserName;
    }

    public void setPurchaserName(String purchaserName) {
        this.purchaserName = purchaserName;
    }

    public String getPurchaserTaxNo() {
        return purchaserTaxNo;
    }

    public void setPurchaserTaxNo(String purchaserTaxNo) {
        this.purchaserTaxNo = purchaserTaxNo;
    }

    public String getPurchaserAddress() {
        return purchaserAddress;
    }

    public void setPurchaserAddress(String purchaserAddress) {
        this.purchaserAddress = purchaserAddress;
    }

    public String getPurchaserTel() {
        return purchaserTel;
    }

    public void setPurchaserTel(String purchaserTel) {
        this.purchaserTel = purchaserTel;
    }

    public String getPurchaserBankName() {
        return purchaserBankName;
    }

    public void setPurchaserBankName(String purchaserBankName) {
        this.purchaserBankName = purchaserBankName;
    }

    public String getPurchaserBankAccount() {
        return purchaserBankAccount;
    }

    public void setPurchaserBankAccount(String purchaserBankAccount) {
        this.purchaserBankAccount = purchaserBankAccount;
    }

    @Override
    public String toString() {
        return "OpenInvoiceUpdateModel{" +
                "remark='" + remark + '\'' +
                ", purchaserName='" + purchaserName + '\'' +
                ", purchaserTaxNo='" + purchaserTaxNo + '\'' +
                ", purchaserAddress='" + purchaserAddress + '\'' +
                ", purchaserTel='" + purchaserTel + '\'' +
                ", purchaserBankName='" + purchaserBankName + '\'' +
                ", purchaserBankAccount='" + purchaserBankAccount + '\'' +
                '}';
    }
}

==> invoice-client-4.1.54-20231213.034158-4-sources.jar: com/xforceplus/seller/invoice/client/model/open/OpenInvoiceUpdateModel.java <==
package com.xforceplus.seller.invoice.client.model.open;

public class OpenInvoiceUpdateModel {
    private String remark;
    private String purchaserName;
    private String purchaserTaxNo;
    private String purchaserAddress;
    private String purchaserTel;
    private String purchaserBankName;
    private String purchaserBankAccount;
    private String blueRemark;//释放蓝票备注

    public String getBlueRemark() {
        return blueRemark;
    }

    public void setBlueRemark(String blueRemark) {
        this.blueRemark = blueRemark;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getPurchaserName() {
        return purchaserName;
    }

    public void setPurchaserName(String purchaserName) {
        this.purchaserName = purchaserName;
    }

    public String getPurchaserTaxNo() {
        return purchaserTaxNo;
    }

    public void setPurchaserTaxNo(String purchaserTaxNo) {
        this.purchaserTaxNo = purchaserTaxNo;
    }

    public String getPurchaserAddress() {
        return purchaserAddress;
    }

    public void setPurchaserAddress(String purchaserAddress) {
        this.purchaserAddress = purchaserAddress;
    }

    public String getPurchaserTel() {
        return purchaserTel;
    }

    public void setPurchaserTel(String purchaserTel) {
        this.purchaserTel = purchaserTel;
    }

    public String getPurchaserBankName() {
        return purchaserBankName;
    }

    public void setPurchaserBankName(String purchaserBankName) {
        this.purchaserBankName = purchaserBankName;
    }

    public String getPurchaserBankAccount() {
        return purchaserBankAccount;
    }

    public void setPurchaserBankAccount(String purchaserBankAccount) {
        this.purchaserBankAccount = purchaserBankAccount;
    }

    @Override
    public String toString() {
        return "OpenInvoiceUpdateModel{" +
                "remark='" + remark + '\'' +
                ", purchaserName='" + purchaserName + '\'' +
                ", purchaserTaxNo='" + purchaserTaxNo + '\'' +
                ", purchaserAddress='" + purchaserAddress + '\'' +
                ", purchaserTel='" + purchaserTel + '\'' +
                ", purchaserBankName='" + purchaserBankName + '\'' +
                ", purchaserBankAccount='" + purchaserBankAccount + '\'' +
                '}';
    }
}
